Function tracing_test::internal::logs_assert
source · pub fn logs_assert<F>(scope: &str, f: F) -> Result<(), String>where
F: Fn(&[&str]) -> Result<(), String>,Expand description
Run a function against a slice of logs for the specified scope and return its result.
This function should usually not be used directly, instead use the
logs_assert(F) where F: Fn(&[&str]) -> Result<(), String> function
injected by the #[traced_test] macro.